/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.basic;

import java.util.List;

import junit.framework.TestCase;

import org.apache.log4j.Logger;
import org.junit.Before;
import org.junit.Test;
import org.kemet.orm.DAL;
import org.kemet.orm.castor.Item;
import org.kemet.orm.castor.Phonogram;
import org.kemet.orm.castor.Sign;
import org.kemet.tests.IAttr;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>DAL Tests.</b>
 * </p>
 * 
 * @since 0.6
 */
public class TestDAL extends TestCase implements IAttr {
	static Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>current data acces layer (DAL).</b>
	 * </p>
	 */
	private DAL dal;

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Before
	public void setUp() {
		try {
			dal = new DAL(XMLPath, new String[] { file1, file2, file3 });
		} catch (Exception e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>test : verify if there are DATA.</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Test
	public void testLoad() {
		Sign[] hiero = dal.getHieroglyphs();
		assertTrue(hiero.length > 0);

		Phonogram[] phono = dal.getPhonograms();
		assertTrue(phono.length > 0);

		List<Sign> deter = dal.getDeterminers();
		assertTrue(deter.size() > 0);

		List<Sign> ideo = dal.getIdeograms();
		assertTrue(ideo.size() > 0);

		List<Sign> sPro = dal.getSuffixPronouns();
		assertTrue(sPro.size() > 0);

		List<Sign> dPro = dal.getDemonstrativePronouns();
		assertTrue(dPro.size() > 0);

		List<Sign> prep = dal.getPrepositions();
		assertTrue(prep.size() > 0);

		List<Item> items = dal.getLexicographicalItems();
		assertTrue(items.size() > 0);
	}
}
